===========
FuncVerbNet
===========


.. image:: https://img.shields.io/pypi/v/funcverbnet.svg
        :target: https://pypi.python.org/pypi/funcverbnet

.. image:: https://img.shields.io/travis/FudanSELab/funcverbnet.svg
        :target: https://travis-ci.com/FudanSELab/funcverbnet

.. image:: https://readthedocs.org/projects/funcverbnet/badge/?version=latest
        :target: https://funcverbnet.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Provides a knowledge system constructed from functionality categories, verbs, and phrase patterns, as well as functionality for fine-grained analysis of functionality descriptions based on this knowledge system


* Free software: BSD license
* Documentation: https://funcverbnet.readthedocs.io.


Features
--------

* TODO

1. Obtain all functionality categories, functionality verbs and phase patters.
2. Given a functionality description sentence, identify its functionality category, functionality verbs and phase patters.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
